@@ -27,7 +27,7 @@
 #include <debug.h>
 
 typedef struct {
-    gnutls_alert_description alert;
+    gnutls_alert_description_t alert;
     const char *desc;
 } gnutls_alert_entry;
 
@@ -75,13 +75,13 @@ static const gnutls_alert_entry sup_alerts[] = {
 
 /**
   * gnutls_alert_get_name - Returns a string describing the alert number given
-  * @alert: is an alert number &gnutls_session structure.
+  * @alert: is an alert number &gnutls_session_t structure.
   *
   * Returns a string that describes the given alert number or NULL.
   * See gnutls_alert_get().
   *
   **/
-const char *gnutls_alert_get_name(gnutls_alert_level alert)
+const char *gnutls_alert_get_name(gnutls_alert_level_t alert)
 {
     const char *ret = NULL;
 
@@ -92,7 +92,7 @@ const char *gnutls_alert_get_name(gnutls_alert_level alert)
 
 /**
   * gnutls_alert_send - This function sends an alert message to the peer
-  * @session: is a &gnutls_session structure.
+  * @session: is a &gnutls_session_t structure.
   * @level: is the level of the alert
   * @desc: is the alert description
   *
@@ -107,8 +107,8 @@ const char *gnutls_alert_get_name(gnutls_alert_level alert)
   * Returns 0 on success.
   *
   **/
-int gnutls_alert_send(gnutls_session session, gnutls_alert_level level,
-		      gnutls_alert_description desc)
+int gnutls_alert_send(gnutls_session_t session, gnutls_alert_level_t level,
+		      gnutls_alert_description_t desc)
 {
     uint8 data[2];
     int ret;
@@ -244,7 +244,7 @@ int gnutls_error_to_alert(int err, int *level)
  */
 /*-
   * gnutls_alert_send_appropriate - This function sends an alert to the peer depending on the error code
-  * @session: is a &gnutls_session structure.
+  * @session: is a &gnutls_session_t structure.
   * @err: is an integer
   *
   * Sends an alert to the peer depending on the error code returned by a gnutls
@@ -257,7 +257,7 @@ int gnutls_error_to_alert(int err, int *level)
   * been sent to the peer.
   *
   -*/
-int gnutls_alert_send_appropriate(gnutls_session session, int err)
+int gnutls_alert_send_appropriate(gnutls_session_t session, int err)
 {
     int alert;
     int level;
@@ -272,7 +272,7 @@ int gnutls_alert_send_appropriate(gnutls_session session, int err)
 
 /**
   * gnutls_alert_get - Returns the last alert number received.
-  * @session: is a &gnutls_session structure.
+  * @session: is a &gnutls_session_t structure.
   *
   * Returns the last alert number received. This function
   * should be called if GNUTLS_E_WARNING_ALERT_RECEIVED or
@@ -280,7 +280,7 @@ int gnutls_alert_send_appropriate(gnutls_session session, int err)
   * The peer may send alerts if he thinks some things were not 
   * right. Check gnutls.h for the available alert descriptions.
   **/
-gnutls_alert_description gnutls_alert_get(gnutls_session session)
+gnutls_alert_description_t gnutls_alert_get(gnutls_session_t session)
 {
     return session->internals.last_alert;
 }
