@@ -64,7 +64,7 @@ _asn1_get_length_der(const unsigned char *der,int  *len)
       ans=0;
       while(punt<=k) ans=ans*256+der[punt++];
     }
-    else{  /* indefinite length method */
+    else{  /* indefinite lenght method */
       ans=-1;
     }
 
@@ -492,11 +492,11 @@ _asn1_get_indefinite_length_string(const unsigned char* der,int* len)
   * @element: pointer to an ASN1 structure
   * @ider: vector that contains the DER encoding. 
   * @len: number of bytes of *der: der[0]..der[len-1]
-  * @errorDescription: null-terminated string contains details when an error occurred.
+  * Description:
   *
   * Fill the structure *ELEMENT with values of a DER encoding string. The sructure must just be
   * created with function 'create_stucture'.
-  * If an error occurs during the decoding procedure, the *ELEMENT is deleted
+  * If an error accurs during de decoding procedure, the *ELEMENT is deleted
   * and set equal to ASN1_TYPE_EMPTY.
   *
   * Returns:
@@ -514,7 +514,7 @@ asn1_der_decoding(ASN1_TYPE *element,const void *ider,int len,
 {
   node_asn *node,*p,*p2,*p3;
   char temp[128];
-  int counter,len2,len3,len4,move,ris,tlen;
+  int counter,len2,len3,len4,move,ris;
   unsigned char class,*temp2;
   unsigned int tag;
   int indefinite, result;
@@ -686,9 +686,7 @@ asn1_der_decoding(ASN1_TYPE *element,const void *ider,int len,
 	break;
       case TYPE_OBJECT_ID:
 	_asn1_get_objectid_der(der+counter,&len2, temp, sizeof(temp));
-	tlen = strlen(temp);
-	if( tlen > 0)
-	   _asn1_set_value(p,temp,tlen+1);
+	_asn1_set_value(p,temp,strlen(temp)+1);
 	counter+=len2;
 	move=RIGHT;
       break;
@@ -698,9 +696,7 @@ asn1_der_decoding(ASN1_TYPE *element,const void *ider,int len,
 		asn1_delete_structure(element);
 	        return result;
 	}
-	tlen = strlen(temp);
-	if (tlen > 0)
-	   _asn1_set_value(p,temp,tlen+1);
+	_asn1_set_value(p,temp,strlen(temp)+1);
 	counter+=len2;
 	move=RIGHT;
 	break;
@@ -723,7 +719,7 @@ asn1_der_decoding(ASN1_TYPE *element,const void *ider,int len,
 	counter+=len3+len2;
 	move=RIGHT;
 	break;
-      case TYPE_SEQUENCE:  case TYPE_SET:
+      case TYPE_SEQUENCE:  case TYPE_SET:;
 	if(move==UP){
 	  len2=strtol(p->value,NULL,10);
 	  _asn1_set_value(p,NULL,0);
@@ -747,9 +743,7 @@ asn1_der_decoding(ASN1_TYPE *element,const void *ider,int len,
 	  counter+=len2;
 	  if(len3>0){
 	    _asn1_ltostr(counter+len3,temp);
-	    tlen = strlen(temp);
-	    if (tlen > 0)
-	       _asn1_set_value(p,temp,tlen+1);
+	    _asn1_set_value(p,temp,strlen(temp)+1);
 	    move=DOWN; 
 	  }
 	  else if(len3==0){
@@ -807,10 +801,7 @@ asn1_der_decoding(ASN1_TYPE *element,const void *ider,int len,
 	  if(len3){
 	    if(len3>0){ /* definite length method */
 	    _asn1_ltostr(counter+len3,temp);
-	    tlen = strlen(temp);
-	    
-	    if (tlen > 0)
-	       _asn1_set_value(p,temp,tlen+1);
+	    _asn1_set_value(p,temp,strlen(temp)+1);
 	    }
 	    else { /* indefinite length method */
 	      _asn1_set_value(p,"-1",3);	      
@@ -824,6 +815,12 @@ asn1_der_decoding(ASN1_TYPE *element,const void *ider,int len,
 	move=RIGHT;
 	break;
       case TYPE_ANY:
+	/* Check indefinite lenth method in a EXPLICIT TAG */
+	if((p->type&CONST_TAG) && (der[counter-1]==0x80))
+	  indefinite=1;
+	else
+	  indefinite=0;
+
 	tag=_asn1_get_tag_der(der+counter,&class,&len2);
 	len4=_asn1_get_length_der(der+counter+len2,&len3);
 	
@@ -842,12 +839,6 @@ asn1_der_decoding(ASN1_TYPE *element,const void *ider,int len,
 	  counter+=len2+len3;
 	}
 	else{ /* indefinite length */
-	  /* Check indefinite lenth method in an EXPLICIT TAG */
-	  if((p->type&CONST_TAG) && (der[counter-1]==0x80))
-	    indefinite=1;
-	  else
-	    indefinite=0;
-
 	  len2=len-counter;
 	  ris=_asn1_get_indefinite_length_string(der+counter,&len2);
 	  if(ris != ASN1_SUCCESS){
@@ -865,17 +856,17 @@ asn1_der_decoding(ASN1_TYPE *element,const void *ider,int len,
 	  _asn1_set_value(p,temp2,len4);
 	  _asn1_afree(temp2);
 	  counter+=len2;
+	}
 
-	  /* Check if a couple of 0x00 are present due to an EXPLICIT TAG with
-	     an indefinite length method. */
-	  if(indefinite){
-	    if(!der[counter] && !der[counter+1]){ 
-	      counter+=2;
-	    }
-	    else{
-	      asn1_delete_structure(element);
-	      return ASN1_DER_ERROR;
-	    }
+	/* Check if a couple of 0x00 are present due to an EXPLICIT TAG with
+	   a indefinite length method. */
+	if(indefinite){
+	  if(!der[counter] && !der[counter+1]){ 
+	    counter+=2;
+	  }
+	  else{
+	    asn1_delete_structure(element);
+	    return ASN1_DER_ERROR;
 	  }
 	}
 	move=RIGHT;
@@ -921,14 +912,14 @@ asn1_der_decoding(ASN1_TYPE *element,const void *ider,int len,
   * @elementName: name of the element to fill
   * @ider: vector that contains the DER encoding of the whole structure. 
   * @len: number of bytes of *der: der[0]..der[len-1]
-  * @errorDescription: null-terminated string contains details when an error occurred.
+  * @errorDescription: null-terminated string contains details when an arror accured.
   * 
   * Description:
   *
   * Fill the element named ELEMENTNAME with values of a DER encoding string. 
   * The sructure must just be created with function 'create_stucture'.
   * The DER vector must contain the encoding string of the whole STRUCTURE.
-  * If an error occurs during the decoding procedure, the *STRUCTURE is deleted
+  * If an error accurs during the decoding procedure, the *STRUCTURE is deleted
   * and set equal to ASN1_TYPE_EMPTY.
   *
   * Returns:
@@ -947,7 +938,7 @@ asn1_der_decoding_element(ASN1_TYPE *structure,const char *elementName,
   node_asn *node,*p,*p2,*p3,*nodeFound=ASN1_TYPE_EMPTY;
   char temp[128],currentName[MAX_NAME_SIZE*10],*dot_p,*char_p;
   int nameLen=MAX_NAME_SIZE*10-1,state;
-  int counter,len2,len3,len4,move,ris, tlen;
+  int counter,len2,len3,len4,move,ris;
   unsigned char class,*temp2;
   unsigned int tag;
   int indefinite, result;
@@ -967,7 +958,7 @@ asn1_der_decoding_element(ASN1_TYPE *structure,const char *elementName,
     return ASN1_GENERIC_ERROR;
   }
 
-  if((*structure)->name){  /* Has *structure got a name? */
+  if((*structure)->name){  /* Has *structure a name? */
     nameLen-=strlen((*structure)->name);
     if(nameLen>0) strcpy(currentName,(*structure)->name);
     else{
@@ -1162,10 +1153,7 @@ asn1_der_decoding_element(ASN1_TYPE *structure,const char *elementName,
       case TYPE_OBJECT_ID:
 	if(state==FOUND){
 	  _asn1_get_objectid_der(der+counter,&len2, temp, sizeof(temp));
-	  tlen = strlen(temp);
-	  
-	  if (tlen > 0)
-	     _asn1_set_value(p,temp,tlen+1);
+	  _asn1_set_value(p,temp,strlen(temp)+1);
 	  
 	  if(p==nodeFound) state=EXIT;
 	}
@@ -1185,9 +1173,7 @@ asn1_der_decoding_element(ASN1_TYPE *structure,const char *elementName,
 	        return result;
 	  }
 
-	  tlen = strlen(temp);
-	  if (tlen > 0)
-  	     _asn1_set_value(p,temp,tlen+1);
+	  _asn1_set_value(p,temp,strlen(temp)+1);
 	  
 	  if(p==nodeFound) state=EXIT;
 	}
@@ -1263,10 +1249,7 @@ asn1_der_decoding_element(ASN1_TYPE *structure,const char *elementName,
 	    counter+=len2;
 	    if(len3>0){
 	      _asn1_ltostr(counter+len3,temp);
-	      tlen = strlen(temp);
-	      
-	      if(tlen > 0)
-	          _asn1_set_value(p,temp,tlen+1);
+	      _asn1_set_value(p,temp,strlen(temp)+1);
 	      move=DOWN;
 	    }
 	    else if(len3==0){
@@ -1318,10 +1301,7 @@ asn1_der_decoding_element(ASN1_TYPE *structure,const char *elementName,
 	    counter+=len2;
 	    if(len3){
 	      _asn1_ltostr(counter+len3,temp);
-	      tlen = strlen(temp);
-	      
-	      if (tlen > 0)
-	          _asn1_set_value(p,temp,tlen+1);
+	      _asn1_set_value(p,temp,strlen(temp)+1);
 	      p2=p->down;
 	      while((type_field(p2->type)==TYPE_TAG) || (type_field(p2->type)==TYPE_SIZE)) p2=p2->right;
 	      if(p2->right==NULL) _asn1_append_sequence_set(p);
@@ -1333,6 +1313,12 @@ asn1_der_decoding_element(ASN1_TYPE *structure,const char *elementName,
 	
 	break;
       case TYPE_ANY:
+	/* Check indefinite lenth method in a EXPLICIT TAG */
+	if((p->type&CONST_TAG) && (der[counter-1]==0x80))
+	  indefinite=1;
+	else
+	  indefinite=0;
+
 	tag=_asn1_get_tag_der(der+counter,&class,&len2);
 	len4=_asn1_get_length_der(der+counter+len2,&len3);
 	
@@ -1355,12 +1341,6 @@ asn1_der_decoding_element(ASN1_TYPE *structure,const char *elementName,
 	  counter+=len2+len3;
 	}
 	else{ /* indefinite length */
-	  /* Check indefinite lenth method in an EXPLICIT TAG */
-	  if((p->type&CONST_TAG) && (der[counter-1]==0x80))
-	    indefinite=1;
-	  else
-	    indefinite=0;
-
 	  len2=len-counter;
 	  ris=_asn1_get_indefinite_length_string(der+counter,&len2);
 	  if(ris != ASN1_SUCCESS){
@@ -1384,17 +1364,17 @@ asn1_der_decoding_element(ASN1_TYPE *structure,const char *elementName,
 	  }
 
 	  counter+=len2;
+	}
 
-	  /* Check if a couple of 0x00 are present due to an EXPLICIT TAG with
-	     an indefinite length method. */
-	  if(indefinite){
-	    if(!der[counter] && !der[counter+1]){ 
-	      counter+=2;
-	    }
-	    else{
-	      asn1_delete_structure(structure);
-	      return ASN1_DER_ERROR;
-	    }
+	/* Check if a couple of 0x00 are present due to an EXPLICIT TAG with
+	   a indefinite length method. */
+	if(indefinite){
+	  if(!der[counter] && !der[counter+1]){ 
+	    counter+=2;
+	  }
+	  else{
+	    asn1_delete_structure(structure);
+	    return ASN1_DER_ERROR;
 	  }
 	}
 	move=RIGHT;
@@ -1703,6 +1683,12 @@ asn1_der_decoding_startEnd(ASN1_TYPE element,const void *ider,int len,
 	move=RIGHT;
 	break;
       case TYPE_ANY:
+	/* Check indefinite lenth method in a EXPLICIT TAG */
+	if((p->type&CONST_TAG) && (der[counter-1]==0x80))
+	  indefinite=1;
+	else
+	  indefinite=0;
+
 	tag=_asn1_get_tag_der(der+counter,&class,&len2);
 	len4=_asn1_get_length_der(der+counter+len2,&len3);
 	
@@ -1710,26 +1696,20 @@ asn1_der_decoding_startEnd(ASN1_TYPE element,const void *ider,int len,
 	  counter+=len2+len4+len3;
 	}
 	else{ /* indefinite length */
-	  /* Check indefinite lenth method in an EXPLICIT TAG */
-	  if((p->type&CONST_TAG) && (der[counter-1]==0x80))
-	    indefinite=1;
-	  else
-	    indefinite=0;
-	  
 	  len2=len-counter;
 	  ris=_asn1_get_indefinite_length_string(der+counter,&len2);
 	  if(ris != ASN1_SUCCESS)
 	    return ris;
 	  counter+=len2;
+	}
 
-	  /* Check if a couple of 0x00 are present due to an EXPLICIT TAG with
-	     an indefinite length method. */
-	  if(indefinite){
-	    if(!der[counter] && !der[counter+1])
-	      counter+=2;
-	    else
-	      return ASN1_DER_ERROR;
-	  }
+	/* Check if a couple of 0x00 are present due to an EXPLICIT TAG with
+	   a indefinite length method. */
+	if(indefinite){
+	  if(!der[counter] && !der[counter+1])
+	    counter+=2;
+	  else
+	    return ASN1_DER_ERROR;
 	}
 	move=RIGHT;
 	break;
@@ -1762,7 +1742,8 @@ asn1_der_decoding_startEnd(ASN1_TYPE element,const void *ider,int len,
 
 
 /**
-  * asn1_expand_any_defined_by - Expand "ANY DEFINED BY" fields in structure.
+  * asn1_expand_any_defined_by - Expand every "ANY DEFINED BY" fields of 
+  *    structure *ELEMENT with the corresponding type.
   * @definitions: ASN1 definitions
   * @element: pointer to an ASN1 structure
   * Description:
@@ -1957,7 +1938,8 @@ asn1_expand_any_defined_by(ASN1_TYPE definitions,ASN1_TYPE *element)
 
 
 /**
-  * asn1_expand_octet_string - Expand "OCTET STRING" fields in structure.
+  * asn1_expand_octet_string - Expand an "OCTET STRING" fields of 
+  *    structure *ELEMENT with the corresponding type.
   * @definitions: ASN1 definitions
   * @element: pointer to an ASN1 structure
   * @octetName: name of the OCTECT STRING field to expand.
@@ -2088,3 +2070,9 @@ asn1_expand_octet_string(ASN1_TYPE definitions,ASN1_TYPE *element,
   return retCode;
 }
 
+
+
+
+
+
+
